==> org-lsst-ccs-buses-definition-5.3.8-sources.jar: org/lsst/ccs/bus/messages/StatusRaisedAlert.java <==
package org.lsst.ccs.bus.messages;

import org.lsst.ccs.bus.data.Alert;
import org.lsst.ccs.bus.data.RaisedAlertSummary;


/**
 * Base class for all status messages containing an RaisedAlert.
 * A RaisedAlert object is embedded within this StatusRaisedAlert.
 * StatusRaisedAlert provides no encoding as the RaisedAlert object already encodes
 * the original Alerts that triggered the publication.
 * 
 * @author LSST CCS Team
 * 
 */
public final class StatusRaisedAlert extends StatusAlert<Alert, Alert> {

    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = 4320480793736L;
    
    private final String cause;
   
     /**
     * Build a StatusAlert from the provided RaisedAlert.
     *
     * @param alert The RaisedAlert object that caused the publication of this StatusAlert.
     * @param cause What caused the Alert to be raised.
     * @param raisedAlertSummary the summary of all uncleared alerts at the time
     * the object is created.
     */
    public StatusRaisedAlert(Alert alert, String cause, RaisedAlertSummary raisedAlertSummary) {
        super(alert, raisedAlertSummary);
        this.cause = cause;
    }

    /**
     * Get the RaisedAlert contained in this message.
     * @return The RaisedAlert.
     * @throws EmbeddedObjectDeserializationException if the embedded object
     * cannot be de-serialized
     */
    public Alert getRaisedAlert() {
        return getObject();
    }
    
    @Override
    protected Alert encodeObject(Alert obj) {
        return new Alert(obj.getAlertId(),obj.getDescription());
    }
    
    /**
     * Get the String explaining what caused the Alert.
     * @return the cause of the Alert.
     */
    public String getCause() {
        return cause;
    }
    

}

==> org-lsst-ccs-buses-definition-6.1.1-sources.jar: org/lsst/ccs/bus/messages/StatusRaisedAlert.java <==
package org.lsst.ccs.bus.messages;

import org.lsst.ccs.bus.data.Alert;
import org.lsst.ccs.bus.data.RaisedAlertSummary;
import org.lsst.ccs.bus.states.AlertState;


/**
 * Base class for all status messages containing an RaisedAlert.
 * A RaisedAlert object is embedded within this StatusRaisedAlert.
 * StatusRaisedAlert provides no encoding as the RaisedAlert object already encodes
 * the original Alerts that triggered the publication.
 * 
 * @author LSST CCS Team
 * 
 */
public final class StatusRaisedAlert extends StatusAlert<Alert, Alert> {

    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = 4320480793736L;
    
    private final String cause;
    
    private final AlertState raisedAlertState;
    private final AlertState overallAlertState;
    private final int count;
   
     /**
     * Build a StatusAlert from the provided RaisedAlert.
     *
     * @param alert The RaisedAlert object that caused the publication of this StatusAlert.
     * @param cause What caused the Alert to be raised.
     * @param raisedAlertSummary the summary of all uncleared alerts at the time
     * the object is created.
     */
    @Deprecated
    public StatusRaisedAlert(Alert alert, String cause, RaisedAlertSummary raisedAlertSummary) {
        super(alert, raisedAlertSummary);
        this.cause = cause;
        raisedAlertState = raisedAlertSummary.getRaisedAlert(alert.getAlertId()).getLatestAlertState();
        overallAlertState = raisedAlertSummary.getAlertState();
        count = raisedAlertSummary.getRaisedAlert(alert.getAlertId()).getLatestAlertInstance().getCount();
    }

    /**
     * Get the RaisedAlert contained in this message.
     * @return The RaisedAlert.
     * @throws EmbeddedObjectDeserializationException if the embedded object
     * cannot be de-serialized
     */
    public Alert getRaisedAlert() {
        return getObject();
    }
    
    @Override
    protected Alert encodeObject(Alert obj) {
        return new Alert(obj.getAlertId(),obj.getDescription());
    }
    
    /**
     * Get the String explaining what caused the Alert.
     * @return the cause of the Alert.
     */
    public String getCause() {
        return cause;
    }
    
    /**
     * Get the AlertState with which this Alert was raised.
     * @return The AlertState of this raised Alert
     * 
     */
    public AlertState getRaisedAlertState() {
        return raisedAlertState;
    }
    
    /**
     * Get the overall AlertState for this Agent.
     * @return The overall AlertState of this Agent
     * 
     */
    public AlertState getAlertState() {
        return overallAlertState;
    }

    /**
     * Get the number of times this Alert has been raised.
     * @return The number of times this Alert has been raised.
     */
    public int getRaisedAlertCount() {
        return count;
    }
}
